import { addRegulation, getRegulationList, getRegulationById } from '@/services/regulation';
import { PageContainer, ProForm, ProFormTextArea } from '@ant-design/pro-components';
import { Card, Col, message, Row, Space } from 'antd';
import { useNavigate, useSearchParams } from 'react-router-dom';
import { useEffect, useRef, useState } from 'react';
import { queryTable } from '@/utils/request';

export default (props) => {
  const formRef = useRef();
  const idRef = useRef();
  const navigate = useNavigate();

  useEffect(() => {
    getRegulationList({ type: `station` }).then((res) => {
      formRef.current.setFieldsValue(res.records[0]);
      idRef.current = res.records[0].id;
    });
  }, []);

  const onFinish = async (values) => {
    //修改
    const id = idRef.current;
    console.log('id', id)
    addRegulation({ ...values, id }).then((res) => {
      navigate(-1);
      return false;
    })
  };

  return (
    <PageContainer>
      <Card>
        <ProForm
          formRef={formRef}
          layout={'horizontal'}
          labelCol={{ span: 8 }}
          wrapperCol={{ span: 16 }}
          onFinish={onFinish}
          submitter={{
            searchConfig: {
              resetText: '返回',
            },
            onReset: () => navigate(-1),
            render: (props, doms) => {
              return (
                <Row>
                  <Col span={8} offset={11}>
                    <Space>{doms}</Space>
                  </Col>
                </Row>
              );
            },
          }}
        >
          <ProFormTextArea
            label="发布内容"
            placeholder="请输入发布内容"
            rules={[{ required: true, message: '请输入发布内容' }]}
            allowClear={false}
            width={750}
            name="detail"
            request={queryTable(getRegulationList)}
          />
        </ProForm>
      </Card>
    </PageContainer>
  )
}